@@ -691,6 +691,24 @@ class ApiField:
     """"""
     UPDATE_STRATEGY = "updateStrategy"
     """"""
+    FILE_PATH = "filePath"
+    """"""
+    FILE_KEY = "fileKey"
+    """"""
+    LOCAL_ENTITIES_COUNT = "localEntitiesCount"
+    """"""
+    REMOTE_ENTITIES_COUNT = "remoteEntitiesCount"
+    """"""
+    RESTRICTED_IMAGE_IDS = "restrictedImageIds"
+    """"""
+    NUMBER_OF_CLUSTERS = "numberOfClusters"
+    """"""
+    CLUSTERING_METHOD = "clusteringMethod"
+    """"""
+    ERROR_MESSAGE = "errorMessage"
+    """"""
+    UNIQUE_ITEMS = "uniqueItems"
+    """"""
 
 
 def _get_single_item(items):
