@@ -3,7 +3,9 @@ import json
 import os
 import signal
 import sys
+import time
 from contextlib import suppress
+from contextvars import ContextVar
 from functools import wraps
 from pathlib import Path
 from threading import Event as ThreadingEvent
@@ -61,6 +63,10 @@ SUPERVISELY_SERVER_PATH_PREFIX = sly_env.supervisely_server_path_prefix()
 if SUPERVISELY_SERVER_PATH_PREFIX and not SUPERVISELY_SERVER_PATH_PREFIX.startswith("/"):
     SUPERVISELY_SERVER_PATH_PREFIX = f"/{SUPERVISELY_SERVER_PATH_PREFIX}"
 
+HEALTH_ENDPOINTS = ["/health", "/is_ready"]
+
+# Context variable for response time
+response_time_ctx: ContextVar[float] = ContextVar("response_time", default=None)
 
 class ReadyzFilter(logging.Filter):
     def filter(self, record):
@@ -70,11 +76,22 @@ class ReadyzFilter(logging.Filter):
         return True
 
 
+class ResponseTimeFilter(logging.Filter):
+    def filter(self, record):
+        # Check if this is an HTTP access log line by logger name
+        if getattr(record, "name", "") == "uvicorn.access":
+            response_time = response_time_ctx.get(None)
+            if response_time is not None:
+                record.responseTime = int(response_time)
+        return True
+
+
 def _init_uvicorn_logger():
     uvicorn_logger = logging.getLogger("uvicorn.access")
     for handler in uvicorn_logger.handlers:
         handler.setFormatter(create_formatter())
     uvicorn_logger.addFilter(ReadyzFilter())
+    uvicorn_logger.addFilter(ResponseTimeFilter())
 
 
 _init_uvicorn_logger()
@@ -794,6 +811,8 @@ def _init(
 
     @app.middleware("http")
     async def get_state_from_request(request: Request, call_next):
+        # Start timer for response time measurement
+        start_time = time.perf_counter()
         if headless is False:
             await StateJson.from_request(request)
 
@@ -829,6 +848,9 @@ def _init(
         except Exception as exc:
             need_to_handle_error = is_production()
             response = await process_server_error(request, exc, need_to_handle_error)
+        # Calculate response time and set it for uvicorn logger in ms
+        elapsed_ms = round((time.perf_counter() - start_time) * 1000)
+        response_time_ctx.set(elapsed_ms)
         return response
 
     def verify_localhost(request: Request):
@@ -905,7 +927,33 @@ class Application(metaclass=Singleton):
             Callable
         ] = None,  # function to check if the app is ready for requests (e.g serving app: model is served and ready)
         show_header: bool = True,
+        hide_health_check_logs: bool = True,  # whether to hide health check logs in info level
+        health_check_endpoints: Optional[List[str]] = None,  # endpoints to check health of the app
     ):
+        """Initialize the Supervisely Application.
+
+        :param layout: Main layout of the application.
+        :type layout: Widget
+        :param templates_dir: Directory with Jinja2 templates. It is preferred to use `layout` instead of `templates_dir`.
+        :type templates_dir: str, optional
+        :param static_dir: Directory with static files (e.g. CSS, JS), used for serving static content.
+        :type static_dir: str, optional
+        :param hot_reload: Whether to enable hot reload during development (default is False).
+        :type hot_reload: bool, optional
+        :param session_info_extra_content: Additional content to be displayed in the session info area.
+        :type session_info_extra_content: Widget, optional
+        :param session_info_solid: Whether to use solid background for the session info area.
+        :type session_info_solid: bool, optional
+        :param ready_check_function: Function to check if the app is ready for requests.
+        :type ready_check_function: Callable, optional
+        :param show_header: Whether to show the header in the application.
+        :type show_header: bool, optional
+        :param hide_health_check_logs: Whether to hide health check logs in info level.
+        :type hide_health_check_logs: bool, optional
+        :param health_check_endpoints: List of additional endpoints to check health of the app.
+            Add your custom endpoints here to be able to manage logging of health check requests on info level with `hide_health_check_logs`.
+        :type health_check_endpoints: List[str], optional
+        """
         self._favicon = os.environ.get("icon", "https://cdn.supervisely.com/favicon.ico")
         JinjaWidgets().context["__favicon__"] = self._favicon
         JinjaWidgets().context["__no_html_mode__"] = True
@@ -980,6 +1028,17 @@ class Application(metaclass=Singleton):
             hot_reload=hot_reload,
             before_shutdown_callbacks=self._before_shutdown_callbacks,
         )
+
+        # add filter to hide health check logs for info level
+        if health_check_endpoints is None or len(health_check_endpoints) == 0:
+            self._health_check_endpoints = HEALTH_ENDPOINTS
+        else:
+            health_check_endpoints = [endpoint.strip() for endpoint in health_check_endpoints]
+            self._health_check_endpoints = HEALTH_ENDPOINTS + health_check_endpoints
+
+        if hide_health_check_logs:
+            self._setup_health_check_filter()
+
         self.test_client = TestClient(self._fastapi)
 
         if not headless:
@@ -1126,6 +1185,34 @@ class Application(metaclass=Singleton):
     def set_ready_check_function(self, func: Callable):
         self._ready_check_function = func
 
+    def _setup_health_check_filter(self):
+        """Setup filter to hide health check logs for info level."""
+
+        class HealthCheckFilter(logging.Filter):
+            def __init__(self, app_instance):
+                super().__init__()
+                self.app: Application = app_instance
+
+            def filter(self, record):
+                # Hide health check requests if NOT in debug mode
+                if not self.app._fastapi.debug and hasattr(record, "getMessage"):
+                    message = record.getMessage()
+                    # Check if the message contains health check paths
+                    if any(path in message for path in self.app._health_check_endpoints):
+                        return False
+                return True
+
+        # Apply filter to uvicorn access logger
+        health_filter = HealthCheckFilter(self)
+        uvicorn_logger = logging.getLogger("uvicorn.access")
+
+        # Remove old filters of this type, if any (for safety)
+        uvicorn_logger.filters = [
+            f for f in uvicorn_logger.filters if not isinstance(f, HealthCheckFilter)
+        ]
+
+        uvicorn_logger.addFilter(health_filter)
+
 
 def set_autostart_flag_from_state(default: Optional[str] = None):
     """Set `autostart` flag recieved from task state. Env name: `modal.state.autostart`.
