@@ -94,13 +94,16 @@ def _frame_to_annotation(frame: Frame, video_annotation: VideoAnnotation) -> Ann
 
 def _upload_annotations(api: Api, image_ids, frame_indices, video_annotation: VideoAnnotation):
     anns = []
-    for image_id, frame_index in zip(image_ids, frame_indices):
+    for frame_index in frame_indices:
         frame = video_annotation.frames.get(frame_index, None)
         if frame is not None:
             anns.append(_frame_to_annotation(frame, video_annotation))
+        else:
+            anns.append(Annotation(video_annotation.img_size))
     api.annotation.upload_anns(image_ids, anns=anns)
 
 
+
 def _upload_frames(
     api: Api,
     frames: List[np.ndarray],
